@@ -29,6 +29,9 @@ namespace python = boost::python;
 namespace RDKit {
 void expandQuery(QueryAtom *self, const QueryAtom *other,
                  Queries::CompositeQueryType how, bool maintainOrder) {
+  if (!other) {
+    throw_value_error("other Atom is null");
+  }
   if (other->hasQuery()) {
     const QueryAtom::QUERYATOM_QUERY *qry = other->getQuery();
     self->expandQuery(qry->copy(), how, maintainOrder);
@@ -36,6 +39,9 @@ void expandQuery(QueryAtom *self, const QueryAtom *other,
 }
 
 void setQuery(QueryAtom *self, const QueryAtom *other) {
+  if (!other) {
+    throw_value_error("other Atom is null");
+  }
   if (other->hasQuery()) {
     self->setQuery(other->getQuery()->copy());
   }
@@ -281,7 +287,7 @@ struct atom_wrapper {
         .def("GetBonds", AtomGetBonds, python::args("self"),
              "Returns a read-only sequence of the atom's bonds\n")
 
-        .def("Match", (bool(Atom::*)(const Atom *) const) & Atom::Match,
+        .def("Match", (bool (Atom::*)(const Atom *) const) & Atom::Match,
              python::args("self", "what"),
              "Returns whether or not this atom matches another Atom.\n\n"
              "  Each Atom (or query Atom) has a query function which is\n"
@@ -445,14 +451,13 @@ struct atom_wrapper {
              (python::arg("self"), python::arg("includePrivate") = true,
               python::arg("includeComputed") = true,
               python::arg("autoConvertStrings") = true),
-	     getPropsAsDictDocString.c_str())
+             getPropsAsDictDocString.c_str())
 
         .def("UpdatePropertyCache", &Atom::updatePropertyCache,
              (python::arg("self"), python::arg("strict") = true),
-	     "Regenerates computed properties like implicit valence and ring "
+             "Regenerates computed properties like implicit valence and ring "
              "information.\n\n")
 
-
         .def("NeedsUpdatePropertyCache", &Atom::needsUpdatePropertyCache,
              (python::arg("self")),
              "Returns true or false depending on whether implicit and explicit "
